scxpand.core
============

.. automodule:: scxpand.core

   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   evaluation
   inference
   inference_results
   model_types
   prediction
